@@ -11,20 +11,34 @@ from .functions import (
     mobile_certificate,
     mobile_login,
     mobile_login_status,
+    mobile_sign,
+    mobile_sign_status,
     use_config,
 )
 from .model import (
     Error,
     FieldError,
+    File,
+    file,
+    Files,
+    files,
     MobileCertificateResponse,
     MobileLoginResponse,
     MobileLoginStatusResponse,
+    MobileSignResponse,
+    MobileSignStatusResponse,
+    PDF,
+    pdf,
     Response,
 )
 
 __all__ = (
     "Error",
     "FieldError",
+    "File",
+    "file",
+    "Files",
+    "files",
     "get_default_environment",
     "ISignConnection",
     "ISignEnvironment",
@@ -33,9 +47,15 @@ __all__ = (
     "mobile_certificate",
     "mobile_login",
     "mobile_login_status",
+    "mobile_sign",
+    "mobile_sign_status",
     "MobileCertificateResponse",
     "MobileLoginResponse",
     "MobileLoginStatusResponse",
+    "MobileSignResponse",
+    "MobileSignStatusResponse",
+    "PDF",
+    "pdf",
     "Response",
     "SANDBOX",
     "use_config",
